##  Types of Inbound Data Processors
Inbound Data Processor Type | General | Details
---|---|---
inboundFactSheet | Is used to manage fact sheets (create, update, delete). Example configuration can be found in the Admin UI. |  The configuration contains an additional "type" key to define the target Fact Sheet Type to create/update. The configuration needs to provide the name of the Fact Sheet to create and the external ID in case of updating a Fact Sheet. The following field types in Fact Sheet fields can be updated (using the update section): STRING, SINGLE_SELECT, MULTIPLE_SELECT, DOUBLE, INTEGER, LOCATION, LIFECYCLE, EXTERNALID, PROJECT,MILESTONE,FACTSHEETSTATE Changing the Data Processor mode to "delete" will mark the Fact Sheet "archived", so behave the same way as if users selected "Delete" from the UI.
inboundRelation | Is used to manage relations between Fact Sheets (create, update, delete). Example configuration can be found in the Admin UI. |  The configuration needs to provide an external or internal ID of the two Fact Sheets that need to be connected. The type of the relation needs to be provided. Fields configured for the relation can be updated. Supported types are the same as for the inboundFactSheet data processor. ActiveFrom and activeUntil can as well be updated. The expected date format is following the ISO 8601 format (e.g. "2019-08-02T09:03:49+00:00").
inboundSubscription | Is used to create, update, or delete subscriptions on fact sheets. |  The processor adds a new subscription to a fact sheet. This doesn't apply to subscriptions of the Accountable type, for which the processor doesn't replace the current subscription. To add a new subscription of the Accountable type, delete the existing subscription first. You can delete subscriptions in one of the following ways:
  * Using the Integration API: See [Deletion of Subscriptions](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio27587cd97a4410148028aef3419a720f__deletion_of_subscriptions).
  * Using the GraphQL API: See [Delete a Fact Sheet Subscription](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-subscriptions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275af7677a4410148931efc16c6b337e__deleting_a_fact_sheet_subscription).
  * In the application UI: Navigate to the Subscriptions tab on a fact sheet and delete the subscriptions that you need. Variables to be set in the output section: "user" (mandatory), "subscriptionType" (mandatory), "subscriptionRoles" (optional, depending on workspace configuration), "comment" (optional, will be ignored if no role given).


inboundDocument | Is used to create, update or delete documents linked to Fact Sheets (create, update, delete). The structure is the same as for the inboundFactSheet data processor. Same matching logic for Fact Sheets applies. The found Fact Sheet will not be modified but a linked document changed according to mode (default is "createOrUpdate"). | The updates section must contain a key "name" or the processor will fail. Other potential keys to be set are "description", "url", "origin" to complete the information for a document that is linked to a Fact Sheet.
inboundTag | Is used to manage Tag Groups (create, update), Tags (create, update, delete) and assignments from Tags to Fact Sheets (create). Example configuration can be found in the Admin UI. | Tags can only be removed completely currently. There is no way to remove tags for given Fact Sheets only. If removal of flags is wanted, a Fact Sheet processor in run 0 needs to be created to delete the tags. In run 1 a processor can then add them back in. If no Tag Group is provided, the processor assumes the default Tag Group ("Other tags"). The processor automatically removes all Fast Sheet assignments if a Tag is deleted.
inboundMetrics | Is used to write a single new point to a configured metrics endpoint. | Metrics can store time series data in SAP LeanIX and become interactive charts to display data. In addition the data can be linked to Fact Sheets, presented to the Dashboard or be displayed within the "Reports" area.
inboundImpact | Is used to write BPM impacts using integration API. | All standard integration API functionality is available. A processor always writes a single impact. In case a list of input data is given where "forEach" can iterate over, multiple impacts can be written by a single processor. Different types of impacts should be split into different processors in order to keep a configuration readable as different impacts have different parameters.
inboundToDo | Is used to write To-do using integration API. |


